Class: AWS::Flow::RetryDefaults

Inherits:
Defaults
  • Object
show all
Defined in:
lib/aws/decider/options.rb

Overview

Defaults for RetryOptions.

Instance Method Summary collapse

Methods inherited from Defaults

#method_missing

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class AWS::Flow::Defaults

Instance Method Details

#backoff_coefficient ⇒ Object

Sets the backoff coefficient to use for retry attempts.



228
# File 'lib/aws/decider/options.rb', line 228

def backoff_coefficient; FlowConstants.exponential_retry_backoff_coefficient; end

#exceptions_to_exclude ⇒ Object

The exceptions that will not initiate a retry attempt. The default is an empty list; no exceptions are excluded.

@see FlowConstants.exponential_retry_exceptions_to_exclude



223
# File 'lib/aws/decider/options.rb', line 223

def exceptions_to_exclude; FlowConstants.exponential_retry_exceptions_to_exclude; end

#exceptions_to_include ⇒ Object

The exceptions that will initiate a retry attempt. The default is to use all exceptions.

@see FlowConstants.exponential_retry_exceptions_to_include



217
# File 'lib/aws/decider/options.rb', line 217

def exceptions_to_include; FlowConstants.exponential_retry_exceptions_to_include; end

#initial_retry_interval ⇒ Object



238
# File 'lib/aws/decider/options.rb', line 238

def initial_retry_interval; FlowConstants.exponential_retry_initial_retry_interval; end

#jitter_function ⇒ Object



235
# File 'lib/aws/decider/options.rb', line 235

def jitter_function; FlowConstants.jitter_function; end

#maximum_attempts ⇒ Object

The default maximum number of attempts to make before the task is marked as failed.

@see FlowConstants.exponential_retry_maximum_attempts



206
# File 'lib/aws/decider/options.rb', line 206

def maximum_attempts; FlowConstants.exponential_retry_maximum_attempts; end

#retry_function ⇒ Object

The default retry function to use.

@see FlowConstants.exponential_retry_function



211
# File 'lib/aws/decider/options.rb', line 211

def retry_function; FlowConstants.exponential_retry_function; end

#should_jitter ⇒ Object

Returns the value of FlowConstants#should_jitter.

Returns:



232
# File 'lib/aws/decider/options.rb', line 232

def should_jitter; FlowConstants.should_jitter; end