Method: AWS::Flow::WorkflowWorker#start
- Defined in:
- lib/aws/decider/worker.rb
#start(should_register = true) ⇒ Object
Starts the workflow with a AWS::Flow::WorkflowTaskPoller.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws/decider/worker.rb', line 210 def start(should_register = true) # TODO check to make sure that the correct properties are set # TODO Register the domain if not already registered # TODO register types to poll # TODO Set up throttler # TODO Set up a timeout on the throttler correctly, # TODO Make this a generic poller, go to the right kind correctly poller = WorkflowTaskPoller.new( @service, @domain, DecisionTaskHandler.new(@workflow_definition_map, @options), @task_list, @options ) register if should_register @logger.debug "Starting an infinite loop to poll and process workflow tasks." loop do run_once(false, poller) end end |